%INTERPOLADOR DE LOS LAR.
%function LARi=interpol(LARact,LARant)
%Entradas:
%LARact:LAR decodificados de la trama actual.
%LARant:LAR decodificados de la trama anterior.
%Salidas:
%LARi:LAR interpolados.
function LARi=interpol(LARact,LARant)              
j=1:8; 
LARi(j)=0.75*LARant(j)+0.25*LARact(j);
LARi(j+8)=0.50*LARant(j)+0.50*LARact(j);
LARi(j+16)=0.25*LARant(j)+0.75*LARact(j);
LARi(j+24)=LARact(j);
